@@ -1717,7 +1717,7 @@ static void ggp_login_to(PurpleAccount *account, uint32_t server)
 	
 	encryption_type = purple_account_get_string(account, "encryption", "none");
 	purple_debug_info("gg", "Requested encryption type: %s\n", encryption_type);
-	if (strcmp(encryption_type, "opportunistic_tls") == 0)
+	if (purple_strequal(encryption_type, "opportunistic_tls"))
 		glp->tls = 1;
 	else
 		glp->tls = 0;
@@ -2012,19 +2012,19 @@ static int ggp_to_gg_status(PurpleStatus *status, char **msg)
 	purple_debug_info("gg", "ggp_to_gg_status: Requested status = %s\n",
 			status_id);
 
-	if (strcmp(status_id, "available") == 0) {
+	if (purple_strequal(status_id, "available")) {
 		new_status = GG_STATUS_AVAIL;
 		new_status_descr = GG_STATUS_AVAIL_DESCR;
-	} else if (strcmp(status_id, "away") == 0) {
+	} else if (purple_strequal(status_id, "away")) {
 		new_status = GG_STATUS_BUSY;
 		new_status_descr = GG_STATUS_BUSY_DESCR;
-	} else if (strcmp(status_id, "unavailable") == 0) {
+	} else if (purple_strequal(status_id, "unavailable")) {
 		new_status = GG_STATUS_DND;
 		new_status_descr = GG_STATUS_DND_DESCR;
-	} else if (strcmp(status_id, "invisible") == 0) {
+	} else if (purple_strequal(status_id, "invisible")) {
 		new_status = GG_STATUS_INVISIBLE;
 		new_status_descr = GG_STATUS_INVISIBLE_DESCR;
-	} else if (strcmp(status_id, "offline") == 0) {
+	} else if (purple_strequal(status_id, "offline")) {
 		new_status = GG_STATUS_NOT_AVAIL;
 		new_status_descr = GG_STATUS_NOT_AVAIL_DESCR;
 	} else {
@@ -2090,7 +2090,7 @@ static void ggp_add_buddy(PurpleConnection *gc, PurpleBuddy *buddy, PurpleGroup
 	gg_add_notify(info->session, ggp_str_to_uin(name));
 
 	account = purple_connection_get_account(gc);
-	if (strcmp(purple_account_get_username(account), name) == 0) {
+	if (purple_strequal(purple_account_get_username(account), name)) {
 		ggp_status_fake_to_self(account);
 	}
 }
@@ -2327,7 +2327,10 @@ static PurplePluginProtocolInfo prpl_info =
 	NULL,				/* set_public_alias */
 	NULL,				/* get_public_alias */
 	NULL,				/* add_buddy_with_invite */
-	NULL				/* add_buddies_with_invite */
+	NULL,				/* add_buddies_with_invite */
+	NULL,				/* get_cb_alias */
+	NULL,				/* chat_can_receive_file */
+	NULL,				/* chat_send_file */
 };
 
 static PurplePluginInfo info = {
@@ -2365,13 +2368,20 @@ static PurplePluginInfo info = {
 	NULL
 };
 
-static void purple_gg_debug_handler(int level, const char * format, va_list args) {
+static void
+purple_gg_debug_handler(int level, const char * format, va_list args)
+{
 	PurpleDebugLevel purple_level;
-	char *msg = g_strdup_vprintf(format, args);
+	char msgbuff[1000];
+	int ret;
 
-	if (!msg) {
+	/* Don't use glib's printf family, since it might not support
+	 * system-specific formatting modifiers (like %Iu for size on win32). */
+	ret = vsnprintf(msgbuff, sizeof(msgbuff) / sizeof(char), format, args);
+
+	if (ret <= 0) {
 		purple_debug_fatal("gg",
-			"failed to vprintf the following message: %s",
+			"failed to printf the following message: %s",
 			format ? format : "(null)\n");
 
 		return;
@@ -2392,8 +2402,7 @@ static void purple_gg_debug_handler(int level, const char * format, va_list args
 			break;
 	}
 
-	purple_debug(purple_level, "gg", "%s", msg);
-	g_free(msg);
+	purple_debug(purple_level, "gg", "%s", msgbuff);
 }
 
 static void init_plugin(PurplePlugin *plugin)
